@@ -13,7 +13,7 @@
 //! DOI:<https://doi.org/10.1145/65979.65981>
 
 // Imports ===================================================================
-use crate::deviceconsts::memory;
+use avr_oxide::deviceconsts::memory;
 
 use core::alloc::{GlobalAlloc, Layout};
 use core::cell::UnsafeCell;
@@ -83,7 +83,7 @@ fn _alloc_error(_: core::alloc::Layout) -> ! {
 #[cfg(target_arch="avr")]
 pub fn initialise() {
   unsafe {
-    let heap = crate::panic_if_none!(GLOBAL.heap.get().as_mut());
+    let heap = avr_oxide::panic_if_none!(GLOBAL.heap.get().as_mut());
     heap.init();
   }
 }
@@ -94,7 +94,7 @@ pub fn initialise() {
  */
 unsafe impl<const H:usize, const S:usize, const S2:usize> GlobalAlloc for GlobalAllocator<H,S,S2> {
   unsafe fn alloc(&self, layout: Layout) -> *mut u8 {
-    let heap = crate::panic_if_none!(self.heap.get().as_mut());
+    let heap = avr_oxide::panic_if_none!(self.heap.get().as_mut());
 
     // Calculate the size we need to allocate for the 'worst case' amount of
     // padding needed to achieve the requested alignment
@@ -107,7 +107,7 @@ unsafe impl<const H:usize, const S:usize, const S2:usize> GlobalAlloc for Global
     let size_words=  ((layout.size() + 1) / 2) + align_words;
 
     // Allocate, including space for padding if needed
-    let ptr = crate::hal::concurrency::interrupt::isolated(||{
+    let ptr = avr_oxide::hal::concurrency::interrupt::isolated(||{
       match heap.bl_new(size_words){
         0 => {
           core::ptr::null_mut()
@@ -147,12 +147,12 @@ unsafe impl<const H:usize, const S:usize, const S2:usize> GlobalAlloc for Global
   }
 
   unsafe fn dealloc(&self, ptr: *mut u8, _layout: Layout) {
-    let heap = crate::panic_if_none!(self.heap.get().as_mut());
+    let heap = avr_oxide::panic_if_none!(self.heap.get().as_mut());
 
     let index0:usize = core::mem::transmute(&heap.v[0]);
     let mut index = ((ptr as usize) - index0)/2;
 
-    crate::hal::concurrency::interrupt::isolated(||{
+    avr_oxide::hal::concurrency::interrupt::isolated(||{
       // Check if this allocation actually contains alignment padding,
       // and if so adjust the pointer
       if heap.v[index-1] > 0 {
@@ -441,7 +441,7 @@ impl<const HEAPSIZE_WORDS: usize, const SEGS: usize, const S21: usize> FirstFitH
 #[cfg(test)]
 mod test {
   use std::vec::Vec;
-  use crate::alloc::*;
+  use avr_oxide::alloc::*;
 
   #[test]
   fn test_create_heap() {
