@@ -3,7 +3,18 @@
  * Developed by Tim Walls <tim.walls@snowgoons.com>
  * Copyright (c) All Rights Reserved, Tim Walls
  */
-//! Device-specific constants
+//! Device-specific constants.  These are determined by the feature flags
+//! configued in your `Cargo.toml`.
+//!
+//! # Features
+//! The following feature flags affect these constants
+//!
+//! | Type | Values |
+//! | ---- | ------ |
+//! | CPU identification | `atmega4809` |
+//! | Clockspeed | `20MHz`, `16MHz` |
+//! | Allocator size | `alloc_small`, `alloc_medium`, `alloc_large` |
+//!
 
 // Imports ===================================================================
 // Declarations ==============================================================
@@ -13,6 +24,8 @@ compile_error!("A clockspeed feature (\"16MHz\", \"20MHz\") must be enabled for
 #[cfg(not(any(feature="atmega4809")))]
 compile_error!("A processor feature (\"atmega4809\") must be enabled for this crate");
 
+#[cfg(not(any(feature="alloc_small",feature="alloc_medium",feature="alloc_large")))]
+compile_error!("An allocator feature (\"alloc_small\", \"alloc_medium\", \"alloc_large\") must be enabled for this crate");
 
 #[cfg(feature = "atmega4809")]
 pub mod memory {
@@ -36,6 +49,11 @@ pub mod memory {
     pub        const HEAPSIZE : usize = 3072;
     pub(crate) const SMAX     : usize = 32;
   }
+
+  pub mod eeprom {
+    pub const EEPROM_SIZE      : usize = 256;
+    pub const USERROW_SIZE     : usize = 64;
+  }
 }
 
 #[cfg(feature = "atmega4809")]
