@@ -49,18 +49,18 @@
 //! | `atmega4809` | `16MHz`, `20MHz` |
 
 // Imports ===================================================================
-use crate::hal::generic::timer::{TimerControl, TimerIdentity, TimerIsrCallback};
-use crate::hal::generic::timer::TimerMode::Periodic;
-use crate::event::{EventSink, EventSource, OxideEvent, OxideEventEnvelope};
+use avr_oxide::hal::generic::timer::{TimerControl, TimerIdentity, TimerIsrCallback};
+use avr_oxide::hal::generic::timer::TimerMode::Periodic;
+use avr_oxide::event::{EventSink, EventSource, OxideEvent, OxideEventEnvelope};
 use avr_oxide::devices::internal::StaticShareable;
-use crate::deviceconsts::clock::{ MASTER_CLOCK_PRESCALER, MASTER_CLOCK_HZ, MASTER_TICK_FREQ_HZ };
+use avr_oxide::deviceconsts::clock::{ MASTER_CLOCK_PRESCALER, MASTER_CLOCK_HZ, MASTER_TICK_FREQ_HZ };
 use core::marker::PhantomData;
 use core::ops::DerefMut;
 use core::cell::RefCell;
-use crate::alloc::boxed::Box;
-use crate::panic_if_none;
-use crate::util::OwnOrBorrowMut;
-use crate::time::Duration;
+use avr_oxide::alloc::boxed::Box;
+use avr_oxide::panic_if_none;
+use avr_oxide::util::OwnOrBorrowMut;
+use avr_oxide::time::Duration;
 
 // Declarations ==============================================================
 pub trait TickCallback = FnMut(TimerIdentity,Duration) -> ();
