@@ -6,7 +6,7 @@
 //! ATmega4809-specific CPU control block implementation
 
 // Imports ===================================================================
-use crate::{atmel_cpu_tpl};
+use avr_oxide::{atmel_cpu_tpl};
 
 // Declarations ==============================================================
 #[repr(C)]
@@ -29,7 +29,7 @@ atmel_cpu_tpl!(super::ADDR_CPU,super::ADDR_CLKCTRL);
 #[macro_export]
 macro_rules! cpu {
   () => {
-    crate::hal::atmega4809::cpu::instance()
+    avr_oxide::hal::atmega4809::cpu::instance()
   }
 }
 
