@@ -5,8 +5,8 @@
  */
 //! ATmega4809 implementations of the generic device traits
 #![allow(unused)]
-use crate::hal::generic::debugled::DebugLed;
-use crate::hal::generic::serial::SerialNoInterruptTx;
+use avr_oxide::hal::generic::debugled::DebugLed;
+use avr_oxide::hal::generic::serial::SerialNoInterruptTx;
 
 pub mod cpu;
 pub mod timer;
@@ -24,11 +24,11 @@ pub mod eeprom;
 fn panic(info: &core::panic::PanicInfo) -> ! {
   #![allow(deprecated)] // until asm! is implemented for AVR
   unsafe {
-    crate::hal::concurrency::interrupt::disable_interrupts();
+    avr_oxide::hal::concurrency::interrupt::disable_interrupts();
 
     #[cfg(feature="panicout")]
     {
-      use crate::util::{debug_print, debug_print_u16};
+      use avr_oxide::util::{debug_print, debug_print_u16};
       // This doesn't look too pretty, but we can't use any of the standard
       // formatting routines because they require an allocator, which even
       // if we have one, is probably broken right now.
@@ -50,9 +50,11 @@ fn panic(info: &core::panic::PanicInfo) -> ! {
     llvm_asm!("break" :::: "volatile");
 
     loop {
-      crate::hal::atmega4809::debugled::PinE2DebugLed::toggle();
+      #[cfg(feature="arduino")]
+      avr_oxide::hal::atmega4809::debugled::PinE2DebugLed::toggle();
+
       for _i in 0..255 {
-        crate::hal::generic::busy_loop(255);
+        avr_oxide::hal::generic::busy_loop(255);
       }
     }
   }
