@@ -15,35 +15,35 @@
 pub mod panicout {
   #[doc(hidden)]
   #[macro_export]
-  macro_rules! panic_stdout { () => { crate::hal::atmega4809::serial::usart0::instance() }}
+  macro_rules! panic_stdout { () => { avr_oxide::hal::atmega4809::serial::usart0::instance() }}
 }
 
 #[cfg(feature="panicout_usart1")]
 pub mod panicout {
   #[doc(hidden)]
   #[macro_export]
-  macro_rules! panic_stdout { () => { crate::hal::atmega4809::serial::usart1::instance() }}
+  macro_rules! panic_stdout { () => { avr_oxide::hal::atmega4809::serial::usart1::instance() }}
 }
 #[cfg(feature="panicout_usart2")]
 pub mod panicout {
   #[doc(hidden)]
   #[macro_export]
-  macro_rules! panic_stdout { () => { crate::hal::atmega4809::serial::usart2::instance() }}
+  macro_rules! panic_stdout { () => { avr_oxide::hal::atmega4809::serial::usart2::instance() }}
 }
 #[cfg(feature="panicout_usart3")]
 pub mod panicout {
   #[doc(hidden)]
   #[macro_export]
-  macro_rules! panic_stdout { () => { crate::hal::atmega4809::serial::usart3::instance() }}
+  macro_rules! panic_stdout { () => { avr_oxide::hal::atmega4809::serial::usart3::instance() }}
 }
 
 // Code ======================================================================
 #[cfg(feature="usart0")]
 pub mod usart0 {
-  use crate::{atmel_usart_tpl};
-  use crate::hal::generic::serial::base::usart::MuxControl;
+  use avr_oxide::{atmel_usart_tpl};
+  use avr_oxide::hal::generic::serial::base::usart::MuxControl;
   #[cfg(target_arch="avr")]
-  use crate::hal::atmega4809::cpu::PortmuxControl;
+  use avr_oxide::hal::atmega4809::cpu::PortmuxControl;
 
   pub enum SerialPortPins {
     PortA30,
@@ -79,7 +79,7 @@ pub mod usart0 {
   }
 
   atmel_usart_tpl!(super::super::ADDR_USART0,
-    crate::hal::generic::serial::SerialPortIdentity::Usart0,
+    avr_oxide::hal::generic::serial::SerialPortIdentity::Usart0,
     SerialPortPins, 64,
     _ivr_usart0_rcx, _ivr_usart0_tcx, _ivr_usart0_dre);
 
@@ -88,10 +88,10 @@ pub mod usart0 {
 
 #[cfg(feature="usart1")]
 pub mod usart1 {
-  use crate::{atmel_usart_tpl};
-  use crate::hal::generic::serial::base::usart::MuxControl;
+  use avr_oxide::{atmel_usart_tpl};
+  use avr_oxide::hal::generic::serial::base::usart::MuxControl;
   #[cfg(target_arch="avr")]
-  use crate::hal::atmega4809::cpu::PortmuxControl;
+  use avr_oxide::hal::atmega4809::cpu::PortmuxControl;
 
   pub enum SerialPortPins {
     PortC30,
@@ -123,7 +123,7 @@ pub mod usart1 {
   }
 
   atmel_usart_tpl!(super::super::ADDR_USART1,
-    crate::hal::generic::serial::SerialPortIdentity::Usart1,
+    avr_oxide::hal::generic::serial::SerialPortIdentity::Usart1,
     SerialPortPins, 64,
     _ivr_usart1_rcx, _ivr_usart1_tcx, _ivr_usart1_dre);
 
@@ -132,10 +132,10 @@ pub mod usart1 {
 
 #[cfg(feature="usart2")]
 pub mod usart2 {
-  use crate::{atmel_usart_tpl};
-  use crate::hal::generic::serial::base::usart::MuxControl;
+  use avr_oxide::{atmel_usart_tpl};
+  use avr_oxide::hal::generic::serial::base::usart::MuxControl;
   #[cfg(target_arch="avr")]
-  use crate::hal::atmega4809::cpu::PortmuxControl;
+  use avr_oxide::hal::atmega4809::cpu::PortmuxControl;
 
   pub enum SerialPortPins {
     PortF30,
@@ -167,7 +167,7 @@ pub mod usart2 {
   }
 
   atmel_usart_tpl!(super::super::ADDR_USART2,
-    crate::hal::generic::serial::SerialPortIdentity::Usart2,
+    avr_oxide::hal::generic::serial::SerialPortIdentity::Usart2,
     SerialPortPins, 64,
     _ivr_usart2_rcx, _ivr_usart2_tcx, _ivr_usart2_dre);
 
@@ -176,10 +176,10 @@ pub mod usart2 {
 
 #[cfg(feature="usart3")]
 pub mod usart3 {
-  use crate::{atmel_usart_tpl};
-  use crate::hal::generic::serial::base::usart::MuxControl;
+  use avr_oxide::{atmel_usart_tpl};
+  use avr_oxide::hal::generic::serial::base::usart::MuxControl;
   #[cfg(target_arch="avr")]
-  use crate::hal::atmega4809::cpu::PortmuxControl;
+  use avr_oxide::hal::atmega4809::cpu::PortmuxControl;
 
   pub enum SerialPortPins {
     PortB30,
@@ -212,7 +212,7 @@ pub mod usart3 {
   }
 
   atmel_usart_tpl!(super::super::ADDR_USART3,
-    crate::hal::generic::serial::SerialPortIdentity::Usart3,
+    avr_oxide::hal::generic::serial::SerialPortIdentity::Usart3,
     SerialPortPins, 64,
     _ivr_usart3_rcx, _ivr_usart3_tcx, _ivr_usart3_dre);
 }
