@@ -66,8 +66,8 @@ pub trait ClockControl {
 // Code ======================================================================
 #[cfg(target_arch="avr")]
 pub mod base {
-  use crate::{v_read,v_write};
-  use crate::hal::generic::cpu::{ConfigurationChange, Cpu, ClockControl};
+  use avr_oxide::{v_read,v_write};
+  use avr_oxide::hal::generic::cpu::{ConfigurationChange, Cpu, ClockControl};
 
   #[repr(C)]
   pub struct AvrCpuControlBlock {
@@ -171,7 +171,7 @@ pub mod base {
   #[macro_export]
   macro_rules! atmel_cpu_tpl {
     ($cpuref:expr,$clkref:expr) => {
-      use crate::hal::generic::cpu::base::{AvrCpuControlBlock,AvrClockControl};
+      use avr_oxide::hal::generic::cpu::base::{AvrCpuControlBlock,AvrClockControl};
       pub type CpuImpl = AvrCpuControlBlock;
 
       #[inline(always)]
@@ -197,7 +197,7 @@ pub mod dummy {
   //! of Oxide applications on the developer-environment architecture rather
   //! than AVR.  Unlike the 'true' implementations these use std:: functions
   //! like println!() to print to the terminal.
-  use crate::hal::generic::cpu::{ConfigurationChange, Cpu, ClockControl};
+  use avr_oxide::hal::generic::cpu::{ConfigurationChange, Cpu, ClockControl};
 
   pub struct DummyCpuControlBlock {
     pub(crate) sreg: u8
@@ -243,7 +243,7 @@ pub mod dummy {
   #[macro_export]
   macro_rules! atmel_cpu_tpl {
     ($cpuref:expr,$clkref:expr) => {
-      use crate::hal::generic::cpu::dummy::{DummyCpuControlBlock,DummyClockControl};
+      use avr_oxide::hal::generic::cpu::dummy::{DummyCpuControlBlock,DummyClockControl};
       pub type CpuImpl = DummyCpuControlBlock;
 
       static mut DUMMY_CPU: DummyCpuControlBlock = DummyCpuControlBlock {
