@@ -12,7 +12,7 @@
 use core::any::Any;
 use ufmt::derive::uDebug;
 use oxide_macros::Persist;
-use crate::hal::generic::callback::IsrCallback;
+use avr_oxide::hal::generic::callback::IsrCallback;
 
 // Declarations ==============================================================
 /**
@@ -116,7 +116,7 @@ where
 // Code ======================================================================
 #[cfg(target_arch="avr")]
 pub mod base {
-  use crate::hal::generic::port::InterruptMode;
+  use avr_oxide::hal::generic::port::InterruptMode;
 
   pub trait AtmelPortControl {
     /// Set this pin as an output.
@@ -278,9 +278,9 @@ pub mod base {
     ($ref:expr, $portsrc:expr, $isr:ident) => {
       use core::any::Any;
 
-      use crate::hal::generic::port::{PinMode,Pin,PinIdentity,InterruptMode,PinIsrCallback};
-      use crate::hal::generic::port::base::{AtmelPortControl,AvrPortRegisterBlock};
-      use crate::isr_cb_invoke;
+      use avr_oxide::hal::generic::port::{PinMode,Pin,PinIdentity,InterruptMode,PinIsrCallback};
+      use avr_oxide::hal::generic::port::base::{AtmelPortControl,AvrPortRegisterBlock};
+      use avr_oxide::isr_cb_invoke;
 
       pub type PortImpl = AvrPortRegisterBlock;
       pub type PinImpl = AtmelPin;
@@ -342,7 +342,7 @@ pub mod base {
           instance().set_interrupt_mode(self.n, mode)
         }
         fn listen(&self, handler: PinIsrCallback<Self>){
-          crate::hal::concurrency::interrupt::isolated(||{
+          avr_oxide::hal::concurrency::interrupt::isolated(||{
             unsafe {
               PINS[self.n as usize].handler = handler;
             }
@@ -405,7 +405,7 @@ pub mod base {
        */
       #[no_mangle]
       pub unsafe extern "avr-interrupt" fn $isr() {
-        crate::hal::concurrency::interrupt::isr(||{
+        avr_oxide::hal::concurrency::interrupt::isr(||{
           let intflags:u8 = core::ptr::read_volatile(&instance().intflags as *const u8);
           let state:u8    = core::ptr::read_volatile(&instance().inp as *const u8);
           let mut mask    = 0x01;
@@ -425,7 +425,7 @@ pub mod base {
 
 #[cfg(not(target_arch="avr"))]
 pub mod base {
-  use crate::hal::generic::port::InterruptMode;
+  use avr_oxide::hal::generic::port::InterruptMode;
 
   pub trait AtmelPortControl {
     /// Set this pin as an output.
@@ -534,8 +534,8 @@ pub mod base {
     ($ref:expr, $portsrc:expr, $isr:ident) => {
       use core::any::Any;
 
-      use crate::hal::generic::port::{PinMode,Pin,PinIdentity,InterruptMode,PinIsrCallback};
-      use crate::hal::generic::port::base::{AtmelPortControl,DummyPortRegisterBlock};
+      use avr_oxide::hal::generic::port::{PinMode,Pin,PinIdentity,InterruptMode,PinIsrCallback};
+      use avr_oxide::hal::generic::port::base::{AtmelPortControl,DummyPortRegisterBlock};
 
       pub type PortImpl = DummyPortRegisterBlock;
       pub type PinImpl = AtmelPin;
@@ -597,7 +597,7 @@ pub mod base {
           instance().set_interrupt_mode(self.n, mode)
         }
         fn listen(&self, handler: PinIsrCallback<Self>){
-          crate::hal::concurrency::interrupt::isolated(||{
+          avr_oxide::hal::concurrency::interrupt::isolated(||{
             unsafe {
               PINS[self.n as usize].handler = handler;
             }
