@@ -47,7 +47,7 @@ pub trait WatchdogController {
 // Code ======================================================================
 #[cfg(target_arch="avr")]
 pub mod base {
-  use crate::hal::generic::watchdog::WatchdogPeriod;
+  use avr_oxide::hal::generic::watchdog::WatchdogPeriod;
 
   #[repr(C)]
   pub struct AvrWatchdogControlBlock {
@@ -79,9 +79,9 @@ pub mod base {
   #[macro_export]
   macro_rules! atmel_watchdog_tpl {
     ($ref:expr, $cpu:expr) => {
-      use crate::hal::generic::cpu::{Cpu, ConfigurationChange};
-      use crate::hal::generic::watchdog::{WatchdogController,WatchdogPeriod};
-      use crate::hal::generic::watchdog::base::AvrWatchdogControlBlock;
+      use avr_oxide::hal::generic::cpu::{Cpu, ConfigurationChange};
+      use avr_oxide::hal::generic::watchdog::{WatchdogController,WatchdogPeriod};
+      use avr_oxide::hal::generic::watchdog::base::AvrWatchdogControlBlock;
       pub type WatchdogImpl = AvrWatchdogControlBlock;
 
       impl WatchdogController for AvrWatchdogControlBlock {
@@ -137,8 +137,8 @@ pub mod base {
   #[macro_export]
   macro_rules! atmel_watchdog_tpl {
     ($ref:expr, $cpu:expr) => {
-      use crate::hal::generic::watchdog::{WatchdogController,WatchdogPeriod};
-      use crate::hal::generic::watchdog::base::DummyWatchdogControlBlock;
+      use avr_oxide::hal::generic::watchdog::{WatchdogController,WatchdogPeriod};
+      use avr_oxide::hal::generic::watchdog::base::DummyWatchdogControlBlock;
       pub type WatchdogImpl = DummyWatchdogControlBlock;
 
       impl WatchdogController for DummyWatchdogControlBlock {
