@@ -66,22 +66,28 @@
 //! If the `panic_handler` feature is enabled, a default panic handler will
 //! be provided.
 //!
-//! ### Stdout support
-//! You can enable a global `stdout!()` macro as an alias of one of the
-//! device serial ports, which can be used globally to write to the given
-//! port.  It is still your responsibility to initialise that port with a
+//! ### Panic to serial port support
+//! You can configure a serial port which will be used by the AVRoxide
+//! [panic handler] to output error line information on panic.
+//!
+//! It is your responsibility to initialise that port with a
 //! suitable baud rate/serial protocol as early as possible in your program.
 //!
-//! If a stdout port has been selected, the AVRoxide [panic handler] will also
-//! use this port to output useful (i.e. `file:line:col`) information on
-//! `panic!()`.
+//! | For Processor  | Available panic output Features (pick 1) |
+//! | -------------- | ---------------------------------------- |
+//! | `atmega4809`   | `panicout_usart0`, `panicout_usart1`, `panicout_usart2`, `panicout_usart3` |
 //!
-//! | For Processor  | Available stdout Features (pick 1) |
-//! | -------------- | ---------------------------------- |
-//! | `atmega4809`   | `stdout_usart0`, `stdout_usart1`, `stdout_usart2`, `stdout_usart3` |
+//! > *Important*: Because of the way Rust embeds panic information in your
+//! > binary, enabling this feature can take up a fair amount of Flash memory
+//! > space.  For example, a simple test app that uses 37882 bytes of Flash
+//! > without this feature uses 44330 bytes with it.
+//! >
+//! > Note also that because Rust embeds absolute pathnames for source files
+//! > into the binary, the size of your binary can change depending on where
+//! > (the directory path) you compile it on your development machine!
 //!
 //! ### Dynamic Allocator
-//! A dynamic allocator implementation is available; this will allocate a
+//! A dynamic allocator implementation is provided; this will allocate a
 //! certain amount of the device's memory as a heap for dynamic data
 //! allocation.  More memory allocated to heap means less for stack and
 //! mutable constants, so three different memory models (small, medium, large)
@@ -108,8 +114,9 @@
 //!
 //! use avr_oxide::hal::atmega4809::hardware;
 //! use avr_oxide::alloc::boxed::Box;
+//! use avr_oxide::devices::UsesPin;
 //! use avr_oxide::devices::debouncer::Debouncer;
-//! use avr_oxide::devices::{ OxideLed, OxideButton, OxideSerialPort };
+//! use avr_oxide::devices::{ Handle, OxideLed, OxideButton, OxideSerialPort };
 //! use avr_oxide::hal::generic::serial::{BaudRate, DataBits, Parity, SerialPortMode, StopBits};
 //! use avr_oxide::io::Write;
 //! use avr_oxide::arduino;
@@ -127,29 +134,38 @@
 //!   serial.write(b"Welcome to AVRoxide\n");
 //!
 //!   let green_led = OxideLed::with_pin(arduino.d7);
-//!   let mut green_button = Box::new(OxideButton::using(Debouncer::with_pin(arduino.a2)));
+//!   let mut green_button = Handle::new(OxideButton::using(Debouncer::with_pin(arduino.a2)));
 //!
 //!   green_button.on_click(Box::new(move |_pinid, _state|{
 //!     green_led.toggle();
 //!   }));
 //!
 //!   // Tell the supervisor which devices to listen to
-//!   supervisor.listen(green_button);
+//!   supervisor.listen_handle(green_button);
 //!
 //!   // Now enter the event loop
 //!   supervisor.run();
 //! }
 //! ```
+//!
+//! # Examples and Templates
+//! A more comprehensive example program can be found at [https://avroxi.de/post/an-example-program/].
+//!
+//! 'Empty' templates can be found at the [AVRoxide Templates](https://gitlab.com/snowgoonspub/avr-oxide-templates) gitlab repo,
+//! with all the necessary bits and pieces to get up and running quickly.
+//!
+//! The project homepage is at [avroxi.de](https://avroxi.de), where you'll find
+//! more getting-started style guides and documentation.
+//!
 #![feature(llvm_asm)]
 #![feature(abi_avr_interrupt)]
 #![feature(naked_functions)]
-#![feature(asm)]
-#![feature(global_asm)]
 #![feature(lang_items)]
 #![feature(concat_idents)]
 #![feature(const_maybe_uninit_assume_init)]
 #![feature(maybe_uninit_uninit_array)]
 #![feature(maybe_uninit_extra)]
+#![feature(maybe_uninit_array_assume_init)]
 #![feature(alloc_error_handler)]
 #![feature(dropck_eyepatch)]
 #![feature(trait_alias)]
@@ -159,6 +175,7 @@
 // and then we do want std
 #![cfg_attr(target_arch="avr", no_std)]
 
+extern crate self as avr_oxide;
 
 pub mod io;
 pub mod devices;
@@ -179,6 +196,9 @@ mod boot;
 #[cfg(feature="alloc_ftr")]
 pub mod alloc;
 
+pub mod time;
+pub mod stdout;
+
 pub use oxide_macros::main as main;
 
 /**
@@ -198,6 +218,19 @@ macro_rules! panic_if_err {
   }
 }
 
+/**
+ * Same as `panic_if_error!`, but less typing!
+ */
+#[macro_export]
+macro_rules! pie {
+  ($result:expr) => {
+    match $result {
+      Ok(value) => value,
+      Err(_) => panic!()
+    }
+  }
+}
+
 /**
  * A macro you can use as a substitute for .unwrap() on Options that will simply
  * panic if the result is None.  You will want this to avoid hauling in all of
